@@ -1,3 +1,6 @@
+import warnings
+
+
 class Response:
     """Class to format the response, so that it can be accessed as an object variable.
 
@@ -15,6 +18,7 @@ class Response:
         self._ok: bool = dictionary.get('ok')
         self._status: int = dictionary.get('status')
         self._body: str = dictionary.get('body')
+        self._count: int or None = dictionary.get('count')
 
     @property
     def ok(self) -> bool:
@@ -54,3 +58,15 @@ class Response:
             Returns the dictionary received as arg.
         """
         return self.raw
+
+    @property
+    def count(self) -> int:
+        """Takes the number of un-read emails and returns it in a class. Only works for read email.
+
+        Returns:
+            int:
+            Returns the number of unread emails.
+        """
+        if not isinstance(self._count, int):
+            warnings.warn('count property is valid only for the class ReadEmail')
+        return self._count
